@@ -1,5 +1,4 @@
-from typing import Any, Dict
-from ocp_resources.resource import MissingRequiredArgumentError, NamespacedResource
+from ocp_resources.resource import NamespacedResource
 
 
 class CatalogSource(NamespacedResource):
@@ -11,13 +10,13 @@ class CatalogSource(NamespacedResource):
 
     def __init__(
         self,
-        source_type: str = "",
-        image: str = "",
-        display_name: str = "",
-        publisher: str = "",
-        update_strategy_registry_poll_interval: str = "",
-        **kwargs: Any,
-    ) -> None:
+        source_type=None,
+        image=None,
+        display_name=None,
+        publisher=None,
+        update_strategy_registry_poll_interval=None,
+        **kwargs,
+    ):
         """
         Args:
             source_type (str): Name of the source type.
@@ -34,19 +33,27 @@ class CatalogSource(NamespacedResource):
         self.publisher = publisher
         self.update_strategy_registry_poll_interval = update_strategy_registry_poll_interval
 
-    def to_dict(self) -> None:
+    def to_dict(self):
         super().to_dict()
-        if not self.kind_dict and not self.yaml_file:
+        if not self.yaml_file:
             if not all([self.source_type, self.image, self.display_name, self.publisher]):
-                raise MissingRequiredArgumentError(argument="'source_type', 'image', 'display_name' and 'publisher'")
-
-            self.res["spec"] = {
-                "sourceType": self.source_type,
-                "image": self.image,
-                "displayName": self.display_name,
-                "publisher": self.publisher,
-            }
-            _spec: Dict[str, Any] = self.res["spec"]
-
+                raise ValueError(
+                    "Passing yaml_file or all parameters 'source_type', 'image',"
+                    " 'display_name' and 'publisher' is required."
+                )
+            self.res.update({
+                "spec": {
+                    "sourceType": self.source_type,
+                    "image": self.image,
+                    "displayName": self.display_name,
+                    "publisher": self.publisher,
+                }
+            })
             if self.update_strategy_registry_poll_interval:
-                _spec["updateStrategy"] = {"registryPoll": {"interval": self.update_strategy_registry_poll_interval}}
+                self.res["spec"].update({
+                    "updateStrategy": {
+                        "registryPoll": {
+                            "interval": self.update_strategy_registry_poll_interval,
+                        },
+                    },
+                })
